import React, { CSSProperties } from 'react';
import { InternalAxiosRequestConfig } from 'axios';

interface ButtonProps {
    label: string;
}
declare const Button: (props: ButtonProps) => React.JSX.Element;

interface AvatarEnvisionProps {
    user: {
        firstName: string;
        lastName: string;
        avatar: string | null;
    };
    backgroundColor: string;
    color: string;
    style?: React.CSSProperties;
}
declare function Avatar(props: AvatarEnvisionProps): React.JSX.Element;

type LoadingCircularProgressProps = {
    open: boolean;
    styles?: CSSProperties;
};
declare function LoadingCircularProgress(props: LoadingCircularProgressProps): React.JSX.Element;

declare enum CommonSize {
    small = 0,
    medium = 1,
    large = 2
}

declare enum Gender {
    Male = "Male",
    Female = "Female"
}

declare enum AgeGroup {
    Adult = "Adult",
    Child = "Child",
    Infant = "Infant"
}

declare enum ContactPhoneType {
    Unknown = "Unknown",
    BusinessPhone = "BusinessPhone",
    HomePhoneNumber = "HomePhoneNumber",
    MobilePhone = "MobilePhone"
}

interface Address {
    street?: string | undefined;
    number?: string | undefined;
    complement?: string | undefined;
    zipCode?: string | undefined;
    neighborhood?: string | undefined;
    city?: string | undefined;
    state?: string | undefined;
    countryCode?: string | undefined;
    longitude?: number | undefined;
    latitude?: number | undefined;
}

interface Phone {
    countryCallingCode?: string | undefined;
    countryCode?: string | undefined;
    areaCode?: string | undefined;
    phoneNumber?: string | undefined;
    contactType?: ContactPhoneType;
}

interface ContactInformation {
    email?: string | undefined;
    phone?: Phone;
    address?: Address;
}

interface FrequentFlyer {
    airCompanyCode?: string | undefined;
    number?: string | undefined;
    travellerName?: string | undefined;
}

interface TravellerBasicInfo {
    ageGroup?: AgeGroup;
}

interface Traveller extends TravellerBasicInfo {
    firstName?: string | undefined;
    middleName?: string | undefined;
    lastName?: string | undefined;
    nationality?: string | undefined;
    gender?: Gender;
    birthDate?: Date | undefined;
    externalProperties?: {
        [key: string]: string;
    } | undefined;
    frequentFlyers?: FrequentFlyer[] | undefined;
    documents?: Document[] | undefined;
    redressNnumber?: string | undefined;
    contactInformation?: ContactInformation;
    readonly fullName?: string | undefined;
}

interface DBRecord {
    id?: number;
    active?: boolean;
    creationTime?: Date | undefined;
    lastUpdateTime?: Date | undefined;
    isDeleted?: boolean;
}

interface AirCompany extends DBRecord {
    code?: string | undefined;
    name?: string | undefined;
    displayName?: string | undefined;
    showOnEngine?: boolean;
}

type TravelersDetailProps = {
    travelers: Traveller[];
};
declare function TravelersDetail(props: TravelersDetailProps): React.JSX.Element;

declare function addTravelersDetailTranslationResources(i18nInstance: any): void;

interface Person {
    id: number;
    userId: number;
    firstName: string;
    lastName: string;
    email: string;
    birthDate: Date;
    avatar: string | null;
    phone: string;
    gender: Gender;
    traveler: Traveller;
}

declare function convertLoggedUserToPerson(id: number, displayName: string, photoURL?: string, email?: string): Person;

declare function convertDateFieldToDateOnly(config: InternalAxiosRequestConfig<any>, field: string): void;

declare function stringToHslColor(str: string, saturation: number, lightness: number): string;

declare function convertDateToDateOnly(date: Date): string;

declare const DEBOUNCE_TIME_DEFAULT = 200;

declare function getDocumentMask(documentType: string): string;
declare function validateCPF(cpf: string): boolean;
declare function sanitizeDocument(document: string): string;

export { Address, AgeGroup, AirCompany, Avatar, Button, CommonSize, ContactInformation, ContactPhoneType, DBRecord, DEBOUNCE_TIME_DEFAULT, FrequentFlyer, Gender, LoadingCircularProgress as Loader, Person, Phone, TravelersDetail, Traveller, TravellerBasicInfo, addTravelersDetailTranslationResources, convertDateFieldToDateOnly, convertDateToDateOnly, convertLoggedUserToPerson, getDocumentMask, sanitizeDocument, stringToHslColor, validateCPF };
